@@ -20,6 +20,20 @@ typedef enum {
 } Bug324535;
 
 
+
+/**
+ * bug_481811:
+ * @x: argument
+ *
+ * http://bugzilla.gnome.org/show_bug.cgi?id=481811
+ **/
+static inline double
+bug_481811(double x)
+{
+    return g_random_double_range(x,x*x);
+}
+
+
 /**
  * bug_501038:
  * @a: value
@@ -155,7 +169,7 @@ typedef int (*bug_512155c_function_pointer_t) (unsigned int arg1,
  * BUG_530758:
  *
  * <![CDATA[http://bugzilla.gnome.org/show_bug.cgi?id=530758#c1]]>
- * 
+ *
  * <ulink url="http://bugzilla.gnome.org/show_bug.cgi?id=530758#c1">Test</ulink>
  */
 #define BUG_530758 "dummy"
@@ -233,6 +247,7 @@ void bug_580300b_get_type(gint a);
 void bug_580300c_get_type();
 extern int bug_580300d_get_type();
 
+void bug_597937(void (*function_arg)(int arg1, char arg2, void *));
 
 long int bug_602518a(void);
 unsigned long int bug_602518b(void);
@@ -247,7 +262,7 @@ unsigned int bug_602518c(void);
  */
 union _Bug165425a {
   int i;
-  float f; 
+  float f;
 };
 typedef union _Bug165425a Bug165425a;
 
@@ -286,5 +301,42 @@ long double bug_607445(long double **a, int n);
 signed long bug_610257(const unsigned char *der, int *len);
 
 
+void bug_623968a(void);
+void bug_623968b(void);
+void bug_623968c(void);
+
+
+#define _BUG_624199(struct_type, n_structs, func) \
+  (struct_type *) (__extension__ ({			\
+    gsize __n = (gsize) (n_structs);			\
+    gsize __s = sizeof (struct_type);			\
+    gpointer __p;					\
+    if (__s == 1)					\
+      __p = g_##func (__n);				\
+    else if (__builtin_constant_p (__n) &&			\
+             (__s == 0 || __n <= G_MAXSIZE / __s))		\
+      __p = g_##func (__n * __s);				\
+    else							\
+      __p = g_##func##_n (__n, __s);			\
+    __p;							\
+  }))
+
+
+const char * const * bug_624200a(void);
+const char ** const bug_624200b(void);
+
+
+/* internal function and macro */
+gchar *_bug_000000a (const gchar *name);
+#define _BUG_000000b (a) (a*a);
+
+#ifndef __GTK_DOC_IGNORE__
+extern int bug_512565(void);
+#endif
+
+void (*bug_638330) (void *arg1,
+     const unsigned char *data,
+     unsigned int length);
+
 #endif // GTKDOC_TESTER_H
 
